@@ -588,3 +588,8 @@ void DeletePasswordJobPrivate::fallbackOnError(const QDBusError &err) {
 
     q->emitFinished();
 }
+
+bool QKeychain::isAvailable()
+{
+    return LibSecretKeyring::isAvailable() || GnomeKeyring::isAvailable() || isKwallet5Available();
+}
